@@ -1,5 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; c-indent-level: 8 -*- */
 /*
+ * Copyright (C) 2009, Juanjo Marín <juanj.marin@juntadeandalucia.es>
  * Copyright (C) 2005, Teemu Tervo <teemu.tervo@gmx.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +22,6 @@
 
 #include <unistd.h>
 #include <string.h>
-#include <sys/wait.h>
 #include <stdlib.h>
 #include <errno.h>
 
@@ -30,17 +30,35 @@
 #include <glib/gstdio.h>
 #include <gio/gio.h>
 
+#ifdef G_OS_WIN32
+# define WIFEXITED(x) ((x) != 3)
+# define WEXITSTATUS(x) (x)
+#else
+# include <sys/wait.h>
+#endif
+
 #include "comics-document.h"
 #include "ev-document-misc.h"
 #include "ev-document-thumbnails.h"
 #include "ev-file-helpers.h"
 
+#ifdef G_OS_WIN32
+/* On windows g_spawn_command_line_sync reads stdout in O_BINARY mode, not in O_TEXT mode.
+ * As a consequence, newlines are in a platform dependent representation (\r\n). This
+ * might be considered a bug in glib.
+ */
+#define EV_EOL "\r\n"
+#else
+#define EV_EOL "\n"
+#endif
+
 typedef enum
 {
 	RARLABS,
 	GNAUNRAR,
 	UNZIP,
-	P7ZIP
+	P7ZIP,
+	TAR
 } ComicBookDecompressType;
 
 typedef struct _ComicsDocumentClass ComicsDocumentClass;
@@ -58,7 +76,6 @@ struct _ComicsDocument
 	GPtrArray *page_names;
 	gchar    *selected_command;
 	gchar    *extract_command, *list_command, *decompress_tmp;
-	gboolean regex_arg;
 	gint     offset;
 	ComicBookDecompressType command_usage;
 };
@@ -71,36 +88,35 @@ struct _ComicsDocument
 
 /**
  * @extract: command line arguments to pass to extract a file from the archive
- *   to stdout. The archive file and the file to extract will be appended after
- *   a "--".
+ *   to stdout.
  * @list: command line arguments to list the archive contents
  * @decompress_tmp: command line arguments to pass to extract the archive
- *   into a directory. The archive file and the directory to extract to will be
- *   appended after a "--".
- * @regex_arg: whether the command expects one filename or accepts a regex (glob?)
- * @offset: the byte offset of the filename on each line in the output of
+ *   into a directory.
+ * @offset: the position offset of the filename on each line in the output of
  *   running the @list command
  */
 typedef struct {
         char *extract;
         char *list;
         char *decompress_tmp;
-        gboolean regex_arg;
         gint offset;
 } ComicBookDecompressCommand;
 
 static const ComicBookDecompressCommand command_usage_def[] = {
         /* RARLABS unrar */
-	{"%s p -c- -ierr", "%s vb -c- -- %s", NULL	       , FALSE, NO_OFFSET},
+	{"%s p -c- -ierr --", "%s vb -c- -- %s", NULL             , NO_OFFSET},
 
         /* GNA! unrar */
-	{NULL		 , "%s t %s"	    , "%s -xf %s %s"   , TRUE , NO_OFFSET},
+	{NULL               , "%s t %s"        , "%s -xf %s %s"   , NO_OFFSET},
 
         /* unzip */
-	{"%s -p -C"	 , "%s -Z -1 -- %s" , NULL	       , TRUE , NO_OFFSET},
+	{"%s -p -C --"      , "%s -Z -1 -- %s" , NULL             , NO_OFFSET},
 
         /* 7zip */
-	{NULL		 , "%s l -- %s"	    , "%s x -y %s -o%s", FALSE, OFFSET_7Z}
+	{NULL               , "%s l -- %s"     , "%s x -y %s -o%s", OFFSET_7Z},
+
+        /* tar */
+	{"%s -xOf"          , "%s -tf %s"      , NULL             , NO_OFFSET}
 };
 
 static void       comics_document_document_thumbnails_iface_init (EvDocumentThumbnailsIface *iface);
@@ -122,39 +138,6 @@ EV_BACKEND_REGISTER_WITH_CODE (ComicsDocument, comics_document,
 						comics_document_document_thumbnails_iface_init);
 	} );
 
-static char *
-comics_regex_quote (const char *s)
-{
-    char *ret, *d;
-
-    d = ret = g_malloc (strlen (s) * 4 + 3);
-    
-    *d++ = '\'';
-
-    for (; *s; s++, d++) {
-	switch (*s) {
-	case '?':
-	case '|':
-	case '[':
-	case ']':
-	case '*':
-	case '\\':
-	    *d++ = '\\';
-	    break;
-	case '\'':
-	    *d++ = '\'';
-	    *d++ = '\\';
-	    *d++ = '\'';
-	    break;
-	}
-	*d = *s;
-    }
-    
-    *d++ = '\'';
-    *d = '\0';
-
-    return ret;
-}
 
 /* This function manages the command for decompressing a comic book */
 static gboolean 
@@ -213,19 +196,19 @@ comics_generate_command_lines (ComicsDocument *comics_document,
 			       GError         **error)
 {
 	gchar *quoted_file;
+	gchar *quoted_command;
 	ComicBookDecompressType type;
 	
 	type = comics_document->command_usage;
 	quoted_file = g_shell_quote (comics_document->archive);
-	
-	comics_document->extract_command = 
-			    g_strdup_printf (command_usage_def[type].extract, 
-				             comics_document->selected_command);
+	quoted_command = g_shell_quote (comics_document->selected_command);
+
+	comics_document->extract_command =
+			    g_strdup_printf (command_usage_def[type].extract,
+				             quoted_command);
 	comics_document->list_command =
-			    g_strdup_printf (command_usage_def[type].list, 
-				             comics_document->selected_command, 
-					     quoted_file);
-	comics_document->regex_arg = command_usage_def[type].regex_arg;
+			    g_strdup_printf (command_usage_def[type].list,
+				             quoted_command, quoted_file);
 	comics_document->offset = command_usage_def[type].offset;
 	if (command_usage_def[type].decompress_tmp) {
 		comics_document->dir = ev_mkdtemp ("evince-comics-XXXXXX", error);
@@ -236,10 +219,10 @@ comics_generate_command_lines (ComicsDocument *comics_document,
 
 		comics_document->decompress_tmp =
 			g_strdup_printf (command_usage_def[type].decompress_tmp, 
-					 comics_document->selected_command, 
-					 quoted_file, 
+					 quoted_command, quoted_file,
 					 comics_document->dir);
 		g_free (quoted_file);
+		g_free (quoted_command);
 
 		if (!comics_decompress_temp_dir (comics_document->decompress_tmp,
 		    comics_document->selected_command, error))
@@ -248,6 +231,7 @@ comics_generate_command_lines (ComicsDocument *comics_document,
 			return TRUE;
 	} else {
 		g_free (quoted_file);
+		g_free (quoted_command);
 		return TRUE;
 	}
 
@@ -350,6 +334,15 @@ comics_check_decompress_command	(gchar          *mime_type,
 				comics_document->command_usage = P7ZIP;
 				return TRUE;
 			}
+	} else if (!strcmp (mime_type, "application/x-cbt") ||
+		   !strcmp (mime_type, "application/x-tar")) {
+		/* tar utility (Tape ARchive) */
+		comics_document->selected_command =
+				g_find_program_in_path ("tar");
+		if (comics_document->selected_command) {
+			comics_document->command_usage = TAR;
+			return TRUE;
+		}
 	} else {
 		g_set_error (error,
 			     EV_DOCUMENT_ERROR,
@@ -431,7 +424,8 @@ comics_document_load (EvDocument *document,
 	}
 
 	/* FIXME: is this safe against filenames containing \n in the archive ? */
-	cb_files = g_strsplit (std_out, "\n", 0);
+	cb_files = g_strsplit (std_out, EV_EOL, 0);
+
 	g_free (std_out);
 
 	if (!cb_files) {
@@ -521,7 +515,7 @@ comics_document_get_page_size (EvDocument *document,
 	guchar buf[1024];
 	gboolean success, got_size = FALSE;
 	gint outpipe = -1;
-	GPid child_pid = -1;
+	GPid child_pid;
 	gssize bytes;
 	GdkPixbuf *pixbuf;
 	gchar *filename;
@@ -596,7 +590,7 @@ comics_document_render_pixbuf (EvDocument      *document,
 	guchar buf[4096];
 	gboolean success;
 	gint outpipe = -1;
-	GPid child_pid = -1;
+	GPid child_pid;
 	gssize bytes;
 	gint width, height;
 	gchar *filename;
@@ -844,17 +838,12 @@ extract_argv (EvDocument *document, gint page)
                 return NULL;
 
 	quoted_archive = g_shell_quote (comics_document->archive);
-	if (comics_document->regex_arg) {
-		quoted_filename = comics_regex_quote (comics_document->page_names->pdata[page]);
-	} else {
-		quoted_filename = g_shell_quote (comics_document->page_names->pdata[page]);
-	}
+	quoted_filename = g_shell_quote (comics_document->page_names->pdata[page]);
 
-	command_line = g_strdup_printf ("%s -- %s %s",
+	command_line = g_strdup_printf ("%s %s %s",
 					comics_document->extract_command,
 					quoted_archive,
 					quoted_filename);
-
 	g_shell_parse_argv (command_line, NULL, &argv, &err);
 
 	if (err) {
