@@ -22,12 +22,11 @@
 #define __DJVU_DOCUMENT_INTERNAL_H__
 
 #include "djvu-document.h"
-#include "djvu-text.h"
 
 #include <libdjvu/ddjvuapi.h>
 
 struct _DjvuDocument {
-	GObject           parent_instance;
+	EvDocument        parent_instance;
 
 	ddjvu_context_t  *d_context;
 	ddjvu_document_t *d_document;
@@ -36,8 +35,6 @@ struct _DjvuDocument {
 
 	gchar            *uri;
 
-	DjvuText         *search;
-        
         /* PS exporter */
         gchar		 *ps_filename;
         GString 	 *opts;
@@ -45,6 +42,7 @@ struct _DjvuDocument {
 
 int  djvu_document_get_n_pages (EvDocument   *document);
 void djvu_handle_events        (DjvuDocument *djvu_document, 
-			        int           wait);
+			        int           wait,
+				GError      **error);
 
 #endif /* __DJVU_DOCUMENT_INTERNAL_H__ */
