@@ -44,12 +44,12 @@ enum {
 
 struct _DviDocumentClass
 {
-	GObjectClass parent_class;
+	EvDocumentClass parent_class;
 };
 
 struct _DviDocument
 {
-	GObject parent_instance;
+	EvDocument parent_instance;
 
 	DviContext *context;
 	DviPageSpec *spec;
@@ -68,7 +68,6 @@ struct _DviDocument
 
 typedef struct _DviDocumentClass DviDocumentClass;
 
-static void dvi_document_document_iface_init            (EvDocumentIface           *iface);
 static void dvi_document_document_thumbnails_iface_init (EvDocumentThumbnailsIface *iface);
 static void dvi_document_file_exporter_iface_init	(EvFileExporterIface 	   *iface);
 static void dvi_document_do_color_special               (DviContext                *dvi,
@@ -230,11 +229,11 @@ dvi_document_finalize (GObject *object)
 	G_OBJECT_CLASS (dvi_document_parent_class)->finalize (object);
 }
 
-
 static void
 dvi_document_class_init (DviDocumentClass *klass)
 {
-	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+	GObjectClass    *gobject_class = G_OBJECT_CLASS (klass);
+	EvDocumentClass *ev_document_class = EV_DOCUMENT_CLASS (klass);
 
 	gobject_class->finalize = dvi_document_finalize;
 
@@ -243,27 +242,12 @@ dvi_document_class_init (DviDocumentClass *klass)
 	mdvi_register_fonts ();
 
 	dvi_context_mutex = g_mutex_new ();
-}
 
-static EvDocumentInfo *
-dvi_document_get_info (EvDocument *document)
-{
-	EvDocumentInfo *info;
-
-	info = g_new0 (EvDocumentInfo, 1);
-
-	return info;
-}
-
-static void
-dvi_document_document_iface_init (EvDocumentIface *iface)
-{
-	iface->load = dvi_document_load;
-	iface->save = dvi_document_save;
-	iface->get_n_pages = dvi_document_get_n_pages;
-	iface->get_page_size = dvi_document_get_page_size;
-	iface->render = dvi_document_render;
-	iface->get_info = dvi_document_get_info;
+	ev_document_class->load = dvi_document_load;
+	ev_document_class->save = dvi_document_save;
+	ev_document_class->get_n_pages = dvi_document_get_n_pages;
+	ev_document_class->get_page_size = dvi_document_get_page_size;
+	ev_document_class->render = dvi_document_render;
 }
 
 static void
