@@ -18,6 +18,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#if !defined (__EV_EVINCE_DOCUMENT_H_INSIDE__) && !defined (EVINCE_COMPILATION)
+#error "Only <evince-document.h> can be included directly."
+#endif
+
 #ifndef EV_DOCUMENT_IMAGES_H
 #define EV_DOCUMENT_IMAGES_H
 
@@ -44,14 +48,14 @@ struct _EvDocumentImagesIface {
 
         /* Methods  */
         GList     *(* get_image_mapping) (EvDocumentImages *document_images,
-					  gint              page);
+					  EvPage           *page);
 	GdkPixbuf *(* get_image)         (EvDocumentImages *document_images,
 					  EvImage          *image);
 };
 
 GType      ev_document_images_get_type            (void) G_GNUC_CONST;
 GList     *ev_document_images_get_image_mapping   (EvDocumentImages *document_images,
-						   gint              page);
+						   EvPage           *page);
 GdkPixbuf *ev_document_images_get_image           (EvDocumentImages *document_images,
 						   EvImage          *image);
 
