@@ -30,8 +30,6 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
-#include "egg-toolbars-model.h"
-
 #include "ev-window.h"
 
 G_BEGIN_DECLS
@@ -50,20 +48,12 @@ typedef struct _EvApplicationClass EvApplicationClass;
 
 GType	          ev_application_get_type	     (void) G_GNUC_CONST;
 EvApplication    *ev_application_get_instance        (void);
-gboolean          ev_application_register_service    (EvApplication   *application);
-void	          ev_application_shutdown	     (EvApplication   *application);
 
-gboolean          ev_application_load_session        (EvApplication   *application,
-						      const gchar    **files);
-gboolean          ev_application_open_window         (EvApplication   *application,
-						      GHashTable      *args,
-						      guint32          timestamp,
-						      GError         **error);
-gboolean          ev_application_open_uri            (EvApplication   *application,
-						      const char      *uri,
-						      GHashTable      *args,
-						      guint            timestamp,
-						      GError         **error);
+void              ev_application_shutdown            (EvApplication   *application);
+gboolean          ev_application_load_session        (EvApplication   *application);
+void              ev_application_open_window         (EvApplication   *application,
+						      GdkScreen       *screen,
+						      guint32          timestamp);
 void              ev_application_open_uri_at_dest    (EvApplication   *application,
 						      const char      *uri,
 						      GdkScreen       *screen,
@@ -75,11 +65,10 @@ void	          ev_application_open_uri_list       (EvApplication   *application,
 		  			              GSList          *uri_list,
 						      GdkScreen       *screen,
     						      guint32          timestamp);
-GList		 *ev_application_get_windows	     (EvApplication   *application);
+gboolean	  ev_application_has_window	     (EvApplication   *application);
+const gchar *     ev_application_get_uri             (EvApplication   *application);
 GObject		 *ev_application_get_media_keys	     (EvApplication   *application);
 
-EggToolbarsModel *ev_application_get_toolbars_model  (EvApplication   *application);
-void              ev_application_save_toolbars_model (EvApplication   *application);
 void 		  ev_application_set_filechooser_uri (EvApplication   *application,
 						      GtkFileChooserAction action,
 						      const gchar     *uri);
@@ -87,14 +76,9 @@ const gchar	 *ev_application_get_filechooser_uri (EvApplication   *application,
 						      GtkFileChooserAction action);
 void		  ev_application_screensaver_enable  (EvApplication   *application);
 void		  ev_application_screensaver_disable (EvApplication   *application);
-GtkPrintSettings *ev_application_get_print_settings  (EvApplication   *application);
-void              ev_application_set_print_settings  (EvApplication   *application,
-						      GtkPrintSettings *settings);
-GtkPageSetup     *ev_application_get_page_setup      (EvApplication   *application);
-void              ev_application_set_page_setup      (EvApplication   *application,
-						      GtkPageSetup    *page_setup);
-const gchar      *ev_application_get_dot_dir         (EvApplication   *application);
-const gchar      *ev_application_get_data_dir         (EvApplication   *application);
+const gchar      *ev_application_get_dot_dir         (EvApplication   *application,
+                                                      gboolean         create);
+const gchar      *ev_application_get_data_dir        (EvApplication   *application);
 
 G_END_DECLS
 
