@@ -16,15 +16,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ev-navigation-action.h,v 1.2 2005/01/11 11:21:52 marco Exp $
  */
 
 #ifndef EV_NAVIGATION_ACTION_H
 #define EV_NAVIGATION_ACTION_H
 
-#include <gtk/gtkaction.h>
+#include <gtk/gtk.h>
 
 #include "ev-history.h"
+#include "ev-link.h"
 
 G_BEGIN_DECLS
 
@@ -39,12 +39,6 @@ typedef struct _EvNavigationAction		EvNavigationAction;
 typedef struct _EvNavigationActionPrivate	EvNavigationActionPrivate;
 typedef struct _EvNavigationActionClass		EvNavigationActionClass;
 
-typedef enum
-{
-	EV_NAVIGATION_DIRECTION_BACK,
-	EV_NAVIGATION_DIRECTION_FORWARD
-} EvNavigationDirection;
-
 struct _EvNavigationAction
 {
 	GtkAction parent;
@@ -56,6 +50,9 @@ struct _EvNavigationAction
 struct _EvNavigationActionClass
 {
 	GtkActionClass parent_class;
+
+	void (* activate_link) (EvNavigationAction *action,
+			        EvLink             *link);
 };
 
 GType	ev_navigation_action_get_type		(void);
